@@ -1,6 +1,6 @@
 # DQAstats - Perform data quality assessment (DQA) of electronic health
 # records (EHR)
-# Copyright (C) 2019-2021 Universitätsklinikum Erlangen
+# Copyright (C) 2019-2022 Universitätsklinikum Erlangen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -157,6 +157,11 @@ test_that("correct functioning of descriptive results", {
   expect_length(rv$conformance$value_conformance, 8)
   expect_false(!any(sapply(rv$conformance$value_conformance, length) == 2))
 
+  do.call(
+    file.remove,
+    list(list.files(tempdir(), pattern = "log$", full.names = TRUE))
+  )
+
 })
 
 
@@ -307,4 +312,9 @@ test_that("correct functioning of descriptive results - single source", {
   )))
   unlink(paste0(output_dir, "_header"), recursive = TRUE)
   unlink(output_dir, recursive = TRUE)
+
+  do.call(
+    file.remove,
+    list(list.files(tempdir(), pattern = "log$", full.names = TRUE))
+  )
 })
